pub enum ArchiveEvent {
Directory {
metadata: FileMetadata,
},
FileStart {
metadata: FileMetadata,
size: u64,
},
FileData(SecureBytes),
FileEnd,
End,
}Expand description
One parsed element of an archive stream, in stream order.
Variants
Directory
A directory entry; metadata.filename() is its relative path.
Fields

metadata: FileMetadataFileStart
Start of a file entry of size content bytes; ArchiveEvent::FileData
events follow, then ArchiveEvent::FileEnd.
FileData(SecureBytes)
A piece of the current file’s content.
FileEnd
The current file’s content is complete.
End
The archive terminator was reached.