decrypt_bytes

Function decrypt_bytes 

pub fn decrypt_bytes(
    ciphertext: &[u8],
    key: &[u8; 32],
    nonce: &[u8; 24],
    aad: &[u8],
) -> Result<(SecureBytes, Algorithm), CryptError>
Decrypts the given ciphertext, returning the plaintext as zeroizing SecureBytes.

Fails if the ciphertext or the associated data does not authenticate.